from tuprolog import Info
from tuprolog.core import *
from tuprolog.core.comparators import *
from tuprolog.core.exception import *
from tuprolog.core.formatters import *
from tuprolog.core.operators import *
from tuprolog.core.visitors import *
from tuprolog.core.parsing import *
from tuprolog.unify import *
from tuprolog.theory import *
from tuprolog.theory.parsing import *
from tuprolog.solve import *

import code

code.interact(local=locals())
