import logging
import jpype
import jpype.imports

from it.unibo.tuprolog.core.exception import TuPrologException
from it.unibo.tuprolog.core.exception import SubstitutionException
from it.unibo.tuprolog.core.exception import SubstitutionApplicationException

logging.debug("Loaded JVM classes from it.unibo.tuprolog.core.exception.*")

